masamune_mail library

Plug-in for sending emails via Sendgrid, Gmail, etc. from servers, etc. using Functions.

To use, import package:masamune_mail/masamune_mail.dart.

Classes

MailMasamuneAdapter
MasamuneAdapter for configuring the mail function.
SendGmailFunctionsAction
FunctionsAction for sending Gmail from the server side.
SendGmailFunctionsActionFunctionsActionResponse
FunctionsAction response to send Gmail from the server side.
SendGridFunctionsAction
FunctionsAction for sending mail from the server side via Sendgrid.
SendGridFunctionsActionFunctionsActionResponse
Response to FunctionsAction to send mail from the server side via Sendgrid.