masamune_mail library
Plug-in for sending emails via Sendgrid, Gmail, etc. from servers, etc. using Functions.
To use, import package:masamune_mail/masamune_mail.dart.
Classes
- MailMasamuneAdapter
-
MasamuneAdapterfor configuring the mail function. - SendGmailFunctionsAction
-
FunctionsActionfor sending Gmail from the server side. - SendGmailFunctionsActionFunctionsActionResponse
-
FunctionsActionresponse to send Gmail from the server side. - SendGridFunctionsAction
-
FunctionsActionfor sending mail from the server side via Sendgrid. - SendGridFunctionsActionFunctionsActionResponse
-
Response to
FunctionsActionto send mail from the server side via Sendgrid.